import numpy as np
from numba import njit, prange
import jax
import jax.numpy as jnp


def loop_body(prev_i):
    a = jnp.array([1, 2, 3])
    a = jnp.fft.fft(a)
    return prev_i + 1, a


def g_inner_jitted(x, n):
    i = 0
    while i < n:
        i, a = loop_body(i)
    return x + i


@jax.jit
def test2():
    for i in range(1000):
        a = jnp.array([1, 2, 3, 4, 5, 6, 7, 10, 8, 8, 9, 9, 9, 342])
        a = jnp.fft.fft(a)


if __name__ == '__main__':
    # print(g_inner_jitted(3, 1))
    test2()
    print('finished')



import os
from setuptools import setup


# Utility function to read the README file.
def read(filename):
    return open(os.path.join(os.path.dirname(__file__), filename)).read()


setup(
    name="phot",
    version="0.2.2",
    author="Chunyu Li",
    author_email="cyli0212@gmail.com",
    description=("A Python library for the simulation of optical fiber transmission."),
    # long_description=read('README.md'),
    url="https://github.com/phot-lab/pyphot",
    package_dir={"phot": "phot"},
    packages=['phot'],
    python_requires=">=3.7",
    install_requires=[
        'matplotlib>=3.5.2',
        'numba>=0.55.2',
        'numpy>=1.22.4',
        'scikit_commpy>=0.7.0',
        'scipy>=1.8.1'
    ]
)
